package com.jdblabs.timestamper.core;

import java.util.Date;

/**
* @author Jonathan Bernard {@literal <jdbernard@gmail.com>}
* This represents a marker on the timeline.
* The date of the marker and the mark cannot be changed once assigned.
*/
public class TimelineMarker implements Comparable<TimelineMarker> {

    private final Date timestamp;
    private final String mark;
    private String notes;

    public TimelineMarker(Date timestamp, String mark, String notes) {
        if (timestamp == null || mark == null)
            throw new IllegalArgumentException("Null timestamp or mark"
                    + " is not permitted.");

        this.timestamp = timestamp;
        this.mark = mark;
        this.notes = notes;
    }

    public Date getTimestamp() { return timestamp; }

    public String getMark() { return mark; }

    public String getNotes() { return notes; }

    public void setNotes(String notes) { this.notes = notes; }

    @Override
    public int compareTo(TimelineMarker that) {
        if (that == null) return Integer.MAX_VALUE;

        int val = this.timestamp.compareTo(that.timestamp);
        if (val == 0) val = this.mark.compareTo(that.mark);

        return val;
    }

    @Override
    public boolean equals(Object o) {
        if (o == null) return false;
        if (!(o instanceof TimelineMarker)) return false;

        TimelineMarker that = (TimelineMarker) o;
        return this.timestamp.equals(that.timestamp) &&
                this.mark.equals(that.mark);
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 61 * hash + (this.timestamp != null ? this.timestamp.hashCode() : 0);
        hash = 61 * hash + (this.mark != null ? this.mark.hashCode() : 0);
        return hash;
    }

}

